==> kubernetes-model-kustomize-6.6.1-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/HelmChartFluent.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface HelmChartFluent<A extends HelmChartFluent<A>> extends Fluent<A>{
  public A addToAdditionalValuesFiles(Integer index,String item);
  public A setToAdditionalValuesFiles(Integer index,String item);
  public A addToAdditionalValuesFiles(java.lang.String... items);
  public A addAllToAdditionalValuesFiles(Collection<String> items);
  public A removeFromAdditionalValuesFiles(java.lang.String... items);
  public A removeAllFromAdditionalValuesFiles(Collection<String> items);
  public List<String> getAdditionalValuesFiles();
  public String getAdditionalValuesFile(Integer index);
  public String getFirstAdditionalValuesFile();
  public String getLastAdditionalValuesFile();
  public String getMatchingAdditionalValuesFile(Predicate<String> predicate);
  public Boolean hasMatchingAdditionalValuesFile(Predicate<String> predicate);
  public A withAdditionalValuesFiles(List<String> additionalValuesFiles);
  public A withAdditionalValuesFiles(java.lang.String... additionalValuesFiles);
  public Boolean hasAdditionalValuesFiles();
  public A addToApiVersions(Integer index,String item);
  public A setToApiVersions(Integer index,String item);
  public A addToApiVersions(java.lang.String... items);
  public A addAllToApiVersions(Collection<String> items);
  public A removeFromApiVersions(java.lang.String... items);
  public A removeAllFromApiVersions(Collection<String> items);
  public List<String> getApiVersions();
  public String getApiVersion(Integer index);
  public String getFirstApiVersion();
  public String getLastApiVersion();
  public String getMatchingApiVersion(Predicate<String> predicate);
  public Boolean hasMatchingApiVersion(Predicate<String> predicate);
  public A withApiVersions(List<String> apiVersions);
  public A withApiVersions(java.lang.String... apiVersions);
  public Boolean hasApiVersions();
  public Boolean getIncludeCRDs();
  public A withIncludeCRDs(Boolean includeCRDs);
  public Boolean hasIncludeCRDs();
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public String getNameTemplate();
  public A withNameTemplate(String nameTemplate);
  public Boolean hasNameTemplate();
  public String getNamespace();
  public A withNamespace(String namespace);
  public Boolean hasNamespace();
  public String getReleaseName();
  public A withReleaseName(String releaseName);
  public Boolean hasReleaseName();
  public String getRepo();
  public A withRepo(String repo);
  public Boolean hasRepo();
  public Boolean getSkipHooks();
  public A withSkipHooks(Boolean skipHooks);
  public Boolean hasSkipHooks();
  public Boolean getSkipTests();
  public A withSkipTests(Boolean skipTests);
  public Boolean hasSkipTests();
  public String getValuesFile();
  public A withValuesFile(String valuesFile);
  public Boolean hasValuesFile();
  public A addToValuesInline(String key,Object value);
  public A addToValuesInline(Map<String,Object> map);
  public A removeFromValuesInline(String key);
  public A removeFromValuesInline(Map<String,Object> map);
  public Map<String,Object> getValuesInline();
  public <K,V>A withValuesInline(Map<String,Object> valuesInline);
  public Boolean hasValuesInline();
  public String getValuesMerge();
  public A withValuesMerge(String valuesMerge);
  public Boolean hasValuesMerge();
  public String getVersion();
  public A withVersion(String version);
  public Boolean hasVersion();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withIncludeCRDs();
  public A withSkipHooks();
  public A withSkipTests();
  
}

==> kubernetes-model-kustomize-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/HelmChartFluent.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface HelmChartFluent<A extends HelmChartFluent<A>> extends Fluent<A>{
  public A addToAdditionalValuesFiles(int index,String item);
  public A setToAdditionalValuesFiles(int index,String item);
  public A addToAdditionalValuesFiles(java.lang.String... items);
  public A addAllToAdditionalValuesFiles(Collection<String> items);
  public A removeFromAdditionalValuesFiles(java.lang.String... items);
  public A removeAllFromAdditionalValuesFiles(Collection<String> items);
  public List<String> getAdditionalValuesFiles();
  public String getAdditionalValuesFile(int index);
  public String getFirstAdditionalValuesFile();
  public String getLastAdditionalValuesFile();
  public String getMatchingAdditionalValuesFile(Predicate<String> predicate);
  public Boolean hasMatchingAdditionalValuesFile(Predicate<String> predicate);
  public A withAdditionalValuesFiles(List<String> additionalValuesFiles);
  public A withAdditionalValuesFiles(java.lang.String... additionalValuesFiles);
  public Boolean hasAdditionalValuesFiles();
  public A addToApiVersions(int index,String item);
  public A setToApiVersions(int index,String item);
  public A addToApiVersions(java.lang.String... items);
  public A addAllToApiVersions(Collection<String> items);
  public A removeFromApiVersions(java.lang.String... items);
  public A removeAllFromApiVersions(Collection<String> items);
  public List<String> getApiVersions();
  public String getApiVersion(int index);
  public String getFirstApiVersion();
  public String getLastApiVersion();
  public String getMatchingApiVersion(Predicate<String> predicate);
  public Boolean hasMatchingApiVersion(Predicate<String> predicate);
  public A withApiVersions(List<String> apiVersions);
  public A withApiVersions(java.lang.String... apiVersions);
  public Boolean hasApiVersions();
  public Boolean getIncludeCRDs();
  public A withIncludeCRDs(Boolean includeCRDs);
  public Boolean hasIncludeCRDs();
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public String getNameTemplate();
  public A withNameTemplate(String nameTemplate);
  public Boolean hasNameTemplate();
  public String getNamespace();
  public A withNamespace(String namespace);
  public Boolean hasNamespace();
  public String getReleaseName();
  public A withReleaseName(String releaseName);
  public Boolean hasReleaseName();
  public String getRepo();
  public A withRepo(String repo);
  public Boolean hasRepo();
  public Boolean getSkipHooks();
  public A withSkipHooks(Boolean skipHooks);
  public Boolean hasSkipHooks();
  public Boolean getSkipTests();
  public A withSkipTests(Boolean skipTests);
  public Boolean hasSkipTests();
  public String getValuesFile();
  public A withValuesFile(String valuesFile);
  public Boolean hasValuesFile();
  public A addToValuesInline(String key,Object value);
  public A addToValuesInline(Map<String,Object> map);
  public A removeFromValuesInline(String key);
  public A removeFromValuesInline(Map<String,Object> map);
  public Map<String,Object> getValuesInline();
  public <K,V>A withValuesInline(Map<String,Object> valuesInline);
  public Boolean hasValuesInline();
  public String getValuesMerge();
  public A withValuesMerge(String valuesMerge);
  public Boolean hasValuesMerge();
  public String getVersion();
  public A withVersion(String version);
  public Boolean hasVersion();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withIncludeCRDs();
  public A withSkipHooks();
  public A withSkipTests();
  
}
